pub struct ExponentialLr { /* private fields */ }Expand description
Exponential learning-rate scheduler.
Every step, the optimizer learning rate is multiplied by gamma:
lr = lr * gamma.
Implementations
Sourceimpl ExponentialLr
impl ExponentialLr
Sourcepub fn new(gamma: f32) -> Result<Self, OptimError>
pub fn new(gamma: f32) -> Result<Self, OptimError>
Creates exponential scheduler with gamma in (0, 1].
Sourcepub fn step<O: LearningRate>(
&mut self,
optimizer: &mut O,
) -> Result<f32, OptimError>
pub fn step<O: LearningRate>( &mut self, optimizer: &mut O, ) -> Result<f32, OptimError>
Advances scheduler by one epoch and returns resulting optimizer LR.