pub struct MultiStepLr { /* private fields */ }Expand description
Multi-step learning-rate scheduler.
Drops the learning rate by gamma at each milestone epoch in milestones.
Implementations
Sourceimpl MultiStepLr
impl MultiStepLr
Sourcepub fn new(milestones: Vec<usize>, gamma: f32) -> Result<Self, OptimError>
pub fn new(milestones: Vec<usize>, gamma: f32) -> Result<Self, OptimError>
Creates multi-step scheduler with sorted milestones and gamma in (0, 1].
pub fn milestones(&self) -> &[usize]
pub fn gamma(&self) -> f32
pub fn epoch(&self) -> usize
pub fn reset(&mut self)
pub fn step<O: LearningRate>( &mut self, optimizer: &mut O, ) -> Result<f32, OptimError>