ReduceLrOnPlateau

Struct ReduceLrOnPlateau 

pub struct ReduceLrOnPlateau { /* private fields */ }
Reduce learning rate when a metric has stopped improving.

When the metric has not improved for patience consecutive calls to ReduceLrOnPlateau::step_with_metric, the learning rate is multiplied by factor (clamped to min_lr).

Implementations

Source

impl ReduceLrOnPlateau

pub fn new( factor: f32, patience: usize, min_lr: f32, ) -> Result<Self, OptimError>

Creates a plateau scheduler.

  • factor in (0, 1]
  • patience >= 1
  • min_lr >= 0 and finite
pub fn factor(&self) -> f32

pub fn patience(&self) -> usize

pub fn min_lr(&self) -> f32

pub fn best_metric(&self) -> f32

pub fn wait(&self) -> usize

pub fn epoch(&self) -> usize

pub fn reset(&mut self)

pub fn step_with_metric<O: LearningRate>( &mut self, metric: f32, optimizer: &mut O, ) -> Result<f32, OptimError>

Steps the scheduler with a metric value. If the metric has not improved for patience consecutive steps, the LR is reduced by factor. Lower metric is considered better.