pub struct RmsProp { /* private fields */ }Expand description
RMSProp optimizer with optional momentum, weight decay, and centered variance.
Implementations
Sourceimpl RmsProp
impl RmsProp
Sourcepub fn new(lr: f32) -> Result<Self, OptimError>
pub fn new(lr: f32) -> Result<Self, OptimError>
Creates RMSProp with required learning rate.
Sourcepub fn with_alpha(self, alpha: f32) -> Result<Self, OptimError>
pub fn with_alpha(self, alpha: f32) -> Result<Self, OptimError>
Sets RMSProp smoothing factor in [0, 1).
Sourcepub fn with_epsilon(self, epsilon: f32) -> Result<Self, OptimError>
pub fn with_epsilon(self, epsilon: f32) -> Result<Self, OptimError>
Sets epsilon value, must be finite and > 0.
Sourcepub fn with_weight_decay(self, weight_decay: f32) -> Result<Self, OptimError>
pub fn with_weight_decay(self, weight_decay: f32) -> Result<Self, OptimError>
Sets L2 weight decay factor in [0, +inf).
Sourcepub fn with_momentum(self, momentum: f32) -> Result<Self, OptimError>
pub fn with_momentum(self, momentum: f32) -> Result<Self, OptimError>
Sets momentum factor in [0, 1).
Sourcepub fn with_centered(self, centered: bool) -> Self
pub fn with_centered(self, centered: bool) -> Self
Enables/disables centered RMSProp variant.
Sourcepub fn clear_state(&mut self)
pub fn clear_state(&mut self)
Drops optimizer state (for example when restarting training).
Sourcepub fn learning_rate(&self) -> f32
pub fn learning_rate(&self) -> f32
Returns current learning rate.
Sourcepub fn set_learning_rate(&mut self, lr: f32) -> Result<(), OptimError>
pub fn set_learning_rate(&mut self, lr: f32) -> Result<(), OptimError>
Overrides current learning rate.
Sourcepub fn step(
&mut self,
parameter_id: u64,
weights: &mut Tensor,
grad: &Tensor,
) -> Result<(), OptimError>
pub fn step( &mut self, parameter_id: u64, weights: &mut Tensor, grad: &Tensor, ) -> Result<(), OptimError>
Applies one update to raw tensor weights.
Sourcepub fn step_graph_node(
&mut self,
graph: &mut Graph,
node: NodeId,
) -> Result<(), OptimError>
pub fn step_graph_node( &mut self, graph: &mut Graph, node: NodeId, ) -> Result<(), OptimError>
Applies one update to a trainable graph node by its NodeId.